@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filterimportertest.h"
@@ -25,7 +14,8 @@ FilterImporterTest::FilterImporterTest(MailImporter::FilterInfo *info)
 
 bool FilterImporterTest::importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, const MailImporter::MessageStatus &status)
 {
-    qDebug() << "FilterImporterTest::importMessage folderName " << folderName << " msgPath " << msgPath;
+    Q_UNUSED(status);
+    qDebug() << "FilterImporterTest::importMessage folderName " << folderName << " msgPath " << msgPath << " duplicateCheck " << duplicateCheck;
     return false;
 }
 
@@ -49,6 +39,10 @@ QString FilterImporterTest::topLevelFolder() const
 
 bool FilterImporterTest::importMessage(const KArchiveFile *file, const QString &folderPath, int &nbTotal, int &fileDone)
 {
+    Q_UNUSED(file);
+    Q_UNUSED(folderPath);
+    Q_UNUSED(nbTotal);
+    Q_UNUSED(fileDone);
     return false;
 }
 
