@@ -1,23 +1,12 @@
-/***************************************************************************
-                          filter_mailapp.cxx  -  OS X Mail App import
-                             -------------------
-    copyright            : (C) 2004 by Chris Howells
-    email                : howells@kde.org
+/*
+  filtermailapp.cpp  -  OS X Mail App import
 
-    Derived from code by:
-    copyright            : (C) 2003 by Laurence Anderson
-    email                : l.d.anderson@warwick.ac.uk
+  SPDX-FileCopyrightText: 2004 Chris Howells <howells@kde.org>
+  Derived from code by:
+  SPDX-FileCopyrightText: 2003 Laurence Anderson <l.d.anderson@warwick.ac.uk>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filtermailapp.h"
 #include "mailimporter_debug.h"
@@ -32,10 +21,6 @@ using namespace MailImporter;
 class MailImporter::FilterMailAppPrivate
 {
 public:
-    FilterMailAppPrivate()
-    {
-    }
-
     QStringList mMboxFiles;
 };
 
@@ -125,7 +110,10 @@ void FilterMailApp::importMails(const QString &maildir)
                 tmp.flush();
                 first_msg = false;
 
-                importMessage(folderName, tmp.fileName(), filterInfo()->removeDupMessage());
+
+                if (!importMessage(folderName, tmp.fileName(), filterInfo()->removeDupMessage())) {
+                    filterInfo()->addErrorLogEntry(i18n("Could not import %1", tmp.fileName()));
+                }
 
                 int currentPercentage = (int)(((float)mbox.pos() / filenameInfo.size()) * 100);
                 filterInfo()->setCurrent(currentPercentage);
